IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'APURAC_GESMINTE' AND
                 TYPE = 'P' 			         AND
                 U.UID = O.UID             	AND
                 U.NAME = USER)
DROP PROCEDURE APURAC_GESMINTE
GO

CREATE PROCEDURE APURAC_GESMINTE(
      @P_CDFILIAPUR  VARCHAR(04),
      @P_CDFILIPROC  VARCHAR(04),
      @P_NRLANCTONF  VARCHAR(10),
      @P_CDCLIENTE   VARCHAR(21),
      @P_DTINICIAL   DATETIME,
      @P_DTFINAL     DATETIME,
      @P_NRAPURACFAT VARCHAR(10),
      @P_IDNFCOMPRA  VARCHAR(01))

AS

   /*Variveis contendo parmetros do faturamento*/
   DECLARE @V_CDEMPRATAC  VARCHAR(2);
   DECLARE @V_CDEMPROPER  VARCHAR(02);

   DECLARE @V_CDTIPOOPER   VARCHAR(2);
   /*Filial que est sendo apurada*/
   DECLARE @V_CDFILIAPUR  VARCHAR(4);

   /*Srie da empresa operacional */
   DECLARE @V_CDSERIEOPER VARCHAR(05);
   DECLARE @V_EXISTEMPR   FLOAT;

   /*Taxa de compra*/
   DECLARE @V_VRPCTXADM   FLOAT;

   DECLARE @V_CDPRPRESERV VARCHAR(10);
   DECLARE @V_CDPRGENEREV VARCHAR(10);
   DECLARE @V_NMPRESTSERV  VARCHAR(50);

   DECLARE @V_NRLANCTONF  VARCHAR(10);
   DECLARE @V_NRLANCESTQ  VARCHAR(10);

   DECLARE @V_NRSEQITPROD VARCHAR(04);

   /*Variveis para gerao da nota fiscal de prestao de servios*/
   DECLARE @V_VRPRESTSERV DOUBLE PRECISION;
   DECLARE @V_VRSERVICO   DOUBLE PRECISION;
   DECLARE @V_VRSERVICOGD DOUBLE PRECISION;
   DECLARE @V_VRSERVICOTU DOUBLE PRECISION;
   DECLARE @V_VRGENEROS   DOUBLE PRECISION;
   DECLARE @V_NMPRGENEREV VARCHAR(50);

   /*Variveis do curosr C_DELETANF*/
   DECLARE @V_CDFILIAL    VARCHAR(04);
   DECLARE @V_NRLANCNF    VARCHAR(10);

BEGIN

   SELECT @V_CDFILIAPUR = MAX(CDFILIAPUR)
   FROM CTRLAPURFAT
   WHERE CDFILIAL    = @P_CDFILIAPUR AND
         NRAPURACFAT = @P_NRAPURACFAT;


   /*Parmetros do faturamento:*/
   SELECT @V_VRPCTXADM   = CONVERT(NUMERIC,ISNULL(MAX(SUBSTRING(PF.DSPARAMFATFI,31,6)), 0)), /*Percentual de Compras/Revenda*/
          @V_CDEMPRATAC  = MAX(SUBSTRING(PF.DSPARAMFATFI,39,2)),  /*Empresa atacadista*/
          @V_CDEMPROPER  = MAX(SUBSTRING(PF.DSPARAMFATFI,41,2)),  /*Empresa operacional*/
          @V_CDPRPRESERV = MAX(SUBSTRING(PG.DSPARAMFATGE,12,10)), /*Codigo da Produto para Servicos Prestados*/
          @V_CDPRGENEREV = MAX(SUBSTRING(PG.DSPARAMFATGE,73,10)), /*Cdigo do produto para Revenda de Gneros*/
          @V_CDTIPOOPER =  MAX(SUBSTRING(PF.DSPARAMFATFI,70,2)) /*TIPO DE OPERACAO --parametros por tipo de faturamento */
          FROM PARAMFILIAL PF, PARAMGERAL PG
   WHERE PF.CDFILIAL = @V_CDFILIAPUR;

   /*Taxa de Compra*/
   SET @V_VRPCTXADM = @V_VRPCTXADM/1000;

   /*Atualizao da chave da apurao na tabela de nota fiscal, s  feito
     quando o usurio escolhe nova verificao na tela, caso contrrio, a
     atualizao  feita no programa*/
   IF @P_IDNFCOMPRA = 'N' BEGIN
      UPDATE NOTAFISCAL
      SET  CDFILIAPFATU  = @P_CDFILIAPUR,
           NRAPFATUTNF   = @P_NRAPURACFAT
      WHERE (CDFILIRECE   = @V_CDFILIAPUR)                      AND
            (CDEMPRESA    = @V_CDEMPRATAC)                       AND
            (DTENTRSAID  BETWEEN  @P_DTINICIAL AND @P_DTFINAL)  AND
            (IDENTRSAIDOP = 'E')                                AND
            (IDSTATUS     <> 'C')                               AND
            ((IDSISTEMA = 'DFE') OR (IDSISTEMA IS NULL))        AND
            ((NRAPFATUTNF IS NULL) OR (NRAPFATUTNF = @P_NRAPURACFAT)) AND
            (CDTIPOOPER IN (SELECT CDTIPOOPER
                            FROM TIPOOPERAC
                            WHERE IDENTRSAIDOP = 'E' AND
                                  IDUTILOPERFAMAN = 'S'));
   END;

   IF (@V_CDTIPOOPER IS NULL) OR (@V_CDTIPOOPER = '  ') BEGIN
      SET @V_CDTIPOOPER = '01';
   END;

   /*Busca da srie da empresa operacional na tabela de filial UTILIZADA PARA GERAR A SERIE DE SAIDA*/
   SELECT @V_CDSERIEOPER = MAX(CDSERIE), @V_EXISTEMPR = COUNT(*)
   FROM FILIAL
   WHERE CDFILIAL  = @V_CDFILIAPUR AND
         CDEMPRESA = @V_CDEMPROPER;

   /*Busca da srie da empresa operacional na tabela de empresas relacionadas*/
   IF (@V_CDSERIEOPER IS NULL) AND (@V_EXISTEMPR = 0) BEGIN
      SELECT @V_CDSERIEOPER = MAX(CDSERIE)
      FROM EMPRCNTRFIL
      WHERE CDFILIAL  = @V_CDFILIAPUR AND
            CDEMPRESA = @V_CDEMPROPER;
   END;

   /*Apaga todas as notas fiscais apuradas anteriormente com mesmo
     numero de apuracao*/

   DECLARE C_DELETANF CURSOR FOR
   SELECT CDFILIAL, NRLANCTONF
   FROM NOTAFISCAL
   WHERE CDFILIAL    = @P_CDFILIAPUR  AND
         NRAPURACFAT = @P_NRAPURACFAT AND
         CDCLIENTE   = @P_CDCLIENTE;
   OPEN C_DELETANF;
   FETCH NEXT FROM C_DELETANF INTO @V_CDFILIAL, @V_NRLANCNF;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      DELETE IMPOSINFUSU
      WHERE CDFILIAL   = @V_CDFILIAL AND
            NRLANCTONF = @V_NRLANCNF;

      EXEC DELETA_NF @V_CDFILIAL, @V_NRLANCNF;

      FETCH NEXT FROM C_DELETANF INTO @V_CDFILIAL, @V_NRLANCNF;

   END;
   CLOSE C_DELETANF;
   DEALLOCATE C_DELETANF;

   SET @V_NRLANCTONF = @P_NRLANCTONF;

   SELECT @V_NMPRGENEREV = MAX(NMPRODUTO)
   FROM PRODUTO
   WHERE CDPRODUTO  =  @V_CDPRGENEREV;

   /*Chamada da apurao Gesto Direta para totalizao dos servios no perodo*/
   EXEC APURAC_GESDIRETA @P_CDFILIPROC, @P_CDCLIENTE, @P_DTINICIAL, @P_DTFINAL, @P_NRAPURACFAT, 'S';


   /*Totalizao dos servios apurados*/
   SELECT @V_VRSERVICOGD = ISNULL(SUM(VRPRECUNITAPGD * NREFETIVOSAPGD),0)
   FROM TRAB_APURAC_GD
   WHERE CDFILIALAPGD  = @P_CDFILIAPUR  AND
         NRAPURACGD    = @P_NRAPURACFAT AND
         CDCLIENTEAPGD = @P_CDCLIENTE;

   SELECT @V_VRSERVICOTU = ISNULL(SUM(VRPRECUNITAPTU * NREFETIVOSAPTU),0)
   FROM TRAB_APURAC_TU
   WHERE CDFILIALAPTU  = @P_CDFILIAPUR  AND
         NRAPURACTU    = @P_NRAPURACFAT AND
         CDCLIENTEAPTU = @P_CDCLIENTE;

   SET @V_VRSERVICO = @V_VRSERVICOGD + @V_VRSERVICOTU;
   /*Totalizao dos documentos de compra*/
   SELECT @V_VRGENEROS = ISNULL(SUM(VRNOTAFISC),0)
   FROM NOTAFISCAL
   WHERE CDFILIAPFATU = @P_CDFILIAPUR AND
         NRAPFATUTNF  = @P_NRAPURACFAT;

   /*Gerao da nota fiscal de prestao de servios
    Valor de Faturamento - (valor da entradas + taxa de compra)*/
   SET @V_VRPRESTSERV =  (@V_VRSERVICO - (@V_VRGENEROS + ((@V_VRGENEROS * @V_VRPCTXADM)/100)));



   IF @V_VRPRESTSERV > 0 BEGIN
      EXEC GERA_NOTAFISCAL_CORPO @P_CDFILIPROC,     @V_CDFILIAPUR,  @V_CDEMPROPER,
                            @V_CDTIPOOPER,     @V_CDSERIEOPER, @P_CDCLIENTE,
                            @P_DTFINAL,        'FAI',        @V_NRLANCTONF,
                            @V_NRLANCESTQ, 'N',          @P_NRAPURACFAT,
                            @V_NRLANCTONF,  NULL,         NULL,
                            NULL,          NULL,         NULL,
                            NULL,          NULL,         NULL,
                            NULL,          NULL,         NULL,
                            NULL,          NULL,         NULL,
                            NULL,          @P_DTFINAL,    NULL;



      EXEC GERA_NOTAFISCAL_PRODUTO @P_CDFILIPROC, @V_NRLANCTONF, @V_CDPRGENEREV,
                              @V_CDPRGENEREV, @V_NMPRGENEREV, 1, @V_VRPRESTSERV, 0,
                              NULL, NULL, NULL, NULL,
                              NULL, NULL;

      EXEC GERA_NOTAFISCAL_FECHAMENTO @P_CDFILIPROC, @V_NRLANCTONF;
   END;

   /*Apaga registros na tabela de trabalho*/
   DELETE FROM TRAB_APURAC_GD
   WHERE CDFILIALAPGD  = @P_CDFILIAPUR  AND
         NRAPURACGD    = @P_NRAPURACFAT AND
         CDCLIENTEAPGD = @P_CDCLIENTE ;
   COMMIT TRANSACTION;      
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'APURAC_GESMINTE','5.01.003';
GO

